==> cxf-testutils-2.0.3.4-fuse-sources.jar: org/apache/type_test/doc/TestSimpleContentExtWithAnyAttributeResponse.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.SimpleContentExtWithAnyAttribute;


/**
 * <p>Java class for testSimpleContentExtWithAnyAttributeResponse element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testSimpleContentExtWithAnyAttributeResponse">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="return" type="{http://apache.org/type_test/types2}SimpleContentExtWithAnyAttribute"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types2}SimpleContentExtWithAnyAttribute"/>
 *           &lt;element name="z" type="{http://apache.org/type_test/types2}SimpleContentExtWithAnyAttribute"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testSimpleContentExtWithAnyAttributeResponse")
public class TestSimpleContentExtWithAnyAttributeResponse {

    @XmlElement(name = "return", namespace = "http://apache.org/type_test/doc", required = true)
    protected SimpleContentExtWithAnyAttribute _return;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected SimpleContentExtWithAnyAttribute y;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected SimpleContentExtWithAnyAttribute z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public SimpleContentExtWithAnyAttribute getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public void setReturn(SimpleContentExtWithAnyAttribute value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public SimpleContentExtWithAnyAttribute getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public void setY(SimpleContentExtWithAnyAttribute value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public SimpleContentExtWithAnyAttribute getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public void setZ(SimpleContentExtWithAnyAttribute value) {
        this.z = value;
    }

}

==> cxf-testutils-2.1.3.18-fuse-sources.jar: org/apache/type_test/doc/TestSimpleContentExtWithAnyAttributeResponse.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.SimpleContentExtWithAnyAttribute;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://apache.org/type_test/types2}SimpleContentExtWithAnyAttribute"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types2}SimpleContentExtWithAnyAttribute"/>
 *         &lt;element name="z" type="{http://apache.org/type_test/types2}SimpleContentExtWithAnyAttribute"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testSimpleContentExtWithAnyAttributeResponse")
public class TestSimpleContentExtWithAnyAttributeResponse {

    @XmlElement(name = "return", required = true)
    protected SimpleContentExtWithAnyAttribute _return;
    @XmlElement(required = true)
    protected SimpleContentExtWithAnyAttribute y;
    @XmlElement(required = true)
    protected SimpleContentExtWithAnyAttribute z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public SimpleContentExtWithAnyAttribute getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public void setReturn(SimpleContentExtWithAnyAttribute value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public SimpleContentExtWithAnyAttribute getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public void setY(SimpleContentExtWithAnyAttribute value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public SimpleContentExtWithAnyAttribute getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleContentExtWithAnyAttribute }
     *     
     */
    public void setZ(SimpleContentExtWithAnyAttribute value) {
        this.z = value;
    }

}
